/*
  Copyright (C) 2000-2003 SKYRIX Software AG

  This file is part of OGo

  OGo is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  OGo is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with OGo; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/
// $Id: LSWSession.h,v 1.2 2003/07/11 16:46:01 jan Exp $

#ifndef __LSWebInterface_LSOffice3_LSWOffice_LSWSession_H__
#define __LSWebInterface_LSOffice3_LSWOffice_LSWSession_H__

#import <Foundation/NSMapTable.h>
#import <NGObjWeb/WOSession.h>
#import <NGObjWeb/WOComponent.h>
#include <LSFoundation/LSCommandFactory.h>

@class NSMutableDictionary, NSDictionary, NSMutableSet, NSNotificationCenter;
@class NSTimeZone, NSFormatter, NSArray, NSUserDefaults, NSMutableArray;
@class NGMimeType;
@class LSSort, LSDBTransaction;
@class EODatabaseChannel, EOAdaptor;
@class WOComponent;
@class OWPasteboard;
@class LSOffice3Session, LSCommandContext;
@class LSWNavigation;
@class NGJavaScriptObjectMappingContext;

@interface LSWSession : WOSession
{
@private
  NSMapTable *name2pb;
  
@private
  LSOffice3Session     *lso;
  id                   activeLogin; // EO of login-account
  
  NSMutableDictionary  *componentsConfig;
  LSWNavigation        *navigation;
  LSSort               *eoSorter;
  NSMapTable           *activationCommandToConfig;
  BOOL                 isAwake;
  NSNotificationCenter *notificationCenter;
  NSString             *lastContextId;

  // persistent components
  NSMutableDictionary  *pComponents;

  // shared objects
  NSFormatter          *formatString;
  NSFormatter          *formatDate;
  NSFormatter          *formatTime;
  NSFormatter          *formatDateTime;
  NSFormatter          *formatDateTimeTZ;

  // localization
  NSArray              *accounts;
  NSArray              *allAccounts;
  NSArray              *teams;
  NSArray              *categories;
  NSArray              *categoryNames;
  NSArray              *dockedProjectInfos;

  // favorites
  NSMutableArray       *favorites;
  id                   choosenFavorite;

  // userDefaults
  NSUserDefaults       *userDefaults;
  
  // JavaScript
  NGJavaScriptObjectMappingContext *jsMapContext;
}

// LSOffice commands

- (LSCommandContext *)commandContext;
- (LSOffice3Session *)skyrixContext;

- (LSSort *)eoSorter;

- (id)activeAccount;
- (NSString *)activeLogin;
- (BOOL)activeAccountIsRoot;

// object labels

- (NSString *)labelForObject:(id)_object;

- (NSTimeZone *)timeZone;
- (NSArray *)timeZones;

- (LSWNavigation *)navigation;

// defaults

- (NSUserDefaults *)userDefaults;

// localization

- (void)setPrimaryLanguage:(NSString *)_language;
- (NSString *)primaryLanguage;

/* JavaScript context */

- (NGJavaScriptObjectMappingContext *)jsMapContext;

@end

@interface WOSession(Pasteboard)

- (OWPasteboard *)pasteboardWithName:(NSString *)_name;
- (OWPasteboard *)pasteboardWithUniqueName;

- (OWPasteboard *)transferPasteboard;
- (void)transferObject:(id)_object owner:(WOComponent *)_owner;
- (NGMimeType *)preferredTransferObjectType;
- (id)getTransferObject;
- (id)removeTransferObject;

@end

@interface WOSession(Activation)

- (WOComponent *)instantiateComponentForCommand:(NSString *)_command
  type:(NGMimeType *)_type;

- (WOComponent *)instantiateComponentForCommand:(NSString *)_command
  type:(NGMimeType *)_type
  object:(id)_object;

@end

@class OWPasteboard, NSArray, NGMimeType;

@interface WOSession(Clipboard)

- (OWPasteboard *)clipboard;
- (NSArray *)clipboardTypesForObject:(id)_object;
- (void)placeInClipboard:(id)_object types:(NSArray *)_types;
- (id)objectInClipboardWithType:(NGMimeType *)_type;
- (void)placeInClipboard:(id)_object;
- (id)objectInClipboard;
- (BOOL)clipboardContainsObject;
- (NSString *)labelForObjectInClipboard;

@end

@class NSString, NSDictionary;

@interface WOSession(Commands)

// running commands

- (id)runCommand1:(NSString *)_command, ...;
- (id)runCommand:(NSString *)_command, ...;
- (id)runCommand:(NSString *)_command arguments:(NSDictionary *)_args;

// Controlling transactions
- (BOOL)commit;
- (BOOL)rollback;
- (BOOL)commitTransaction;   // deprecated
- (BOOL)rollbackTransaction; // deprecated
- (BOOL)isTransactionInProgress;

@end

@class NSArray;

@interface WOSession(UserManagement)

- (void)fetchTeams;
- (void)fetchAccounts;
- (void)fetchAllAccounts;
- (void)fetchCategories;
- (void)fetchResources;
- (void)fetchDockedProjectInfos;
- (NSArray *)teams;
- (NSArray *)locationTeams;
- (NSArray *)teamsWithNames:(NSArray *)_names;
- (NSArray *)accounts;
- (NSArray *)allAccounts;
- (NSArray *)resources;
- (NSArray *)resourceNames;
- (NSArray *)categories;
- (NSArray *)categoryNames;
- (NSArray *)dockProjectInfos;

@end

@class NSFormatter;

@interface WOSession(Formatters)

- (NSFormatter *)formatString;
- (NSFormatter *)formatDate;
- (NSFormatter *)formatTime;
- (NSFormatter *)formatDateTime;
- (NSFormatter *)formatterForValue:(id)_value; // guess formatter

@end

@class NSString;

@interface WOSession(Notifications)

- (void)postChange:(NSString *)_changeName onObject:(id)_object;

- (void)addObserver:(id)observer selector:(SEL)selector 
  name:(NSString*)notificationName object:(id)object;
- (void)removeObserver:(id)observer 
  name:(NSString*)notificationName object:(id)object;
- (void)removeObserver:(id)observer;

@end

@interface WOSession(Favorites)

- (void)addFavorite:(id)_fav;
- (void)removeFavorite:(id)_fav;
- (NSArray *)favorites;

@end

@interface WOSession(PageManagement)

- (WOComponent *)restorePageForContextID:(NSString *)_idx;
- (void)savePage:(WOComponent *)_page;

@end

@interface WOSession(PersistentComponents)

- (NSMutableDictionary *)pComponents;

@end

@interface WOComponent(PersistentComponents)

- (id)persistentInstance;
- (void)registerAsPersistentInstance;

@end

#endif /* __LSWebInterface_LSOffice3_LSWOffice_LSWSession_H__ */
